@@ -16,13 +16,30 @@
  * 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifndef INC_LIBETM_H
+#define INC_LIBETM_H
+
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE
+#endif
+#ifndef _ISOC99_SOURCE
+#define _ISOC99_SOURCE
+#endif
+
 #ifndef FALSE
-# define FALSE		(0)
-#endif
-#ifndef TRUE
-# define TRUE		(!FALSE)
+# ifndef TRUE
+#  define FALSE		(0)
+#  define TRUE		(!FALSE)
+# endif
 #endif
 
+/* would it be better like that?
+#undef FALSE
+#undef TRUE
+typedef enum {
+	FALSE = (0), TRUE = (!FALSE)
+} boolean;*/
+
 #define YES		(1)
 #define NO		(0)
 
@@ -52,3 +69,4 @@
 #include "misc.h"
 #include "error.h"
 #include "win32_specific.h"
+#endif /* INC_LIBETM_H */
