@@ -18,6 +18,9 @@
  * 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifndef INC_LIBETM_MISC_H
+#define INC_LIBETM_MISC_H
+
 const char *lib_version(unsigned int);
 int question(const char *);
-
+#endif /* INC_LIBETM_MISC_H */
