@@ -18,6 +18,9 @@
  * 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifndef INC_LIBETM_WIN32_SPECIFIC_H
+#define INC_LIBETM_WIN32_SPECIFIC_H
+
 #ifdef WIN32_V
 /* return NULL if error */
 const char	*get_appdata_dir();
@@ -33,3 +36,4 @@ int		get_win32_taskbar_height();
  * return NULL if error */
 /*const char 	**find_mac_addresses();*/
 #endif
+#endif /* INC_LIBETM_WIN32_SPECIFIC_H */
